# Edit this configuration file to define what should be installed on
# your system.  Help is available in the configuration.nix(5) man page
# and in the NixOS manual (accessible by running nixos-help).

{ config, pkgs, lib, ... }:

let
  home-manager = builtins.fetchTarball "https://github.com/nix-community/home-manager/archive/release-23.05.tar.gz";
  # python packages to include with python3
  python-packages = import ./python-packages.nix;
in
{
  imports = [
    # Include the results of the hardware scan.
    ./hardware-configuration.nix
    (import "${home-manager}/nixos")
    ./nix-settings.nix
    ./boot.nix
    ./users/servostar/user.nix
    ./.luks-swap.nix
    ./fonts.nix
    ./extra
    ./core
    ./dev
  ];

  hardware.bluetooth.enable = true;
  hardware.opengl.enable = true;
  # for rotation sensors
  hardware.sensor.iio.enable = true;
  # screen and keybord backlight
  hardware.acpilight.enable = true;

  networking.firewall.checkReversePath = false;
  networking.hostName = "servostar-nixos-flex"; # Define your hostname.
  # networking.wireless.enable = true;  # Enables wireless support via wpa_supplicant.

  # Configure network proxy if necessary
  # networking.proxy.default = "http://user:password@proxy:port/";
  # networking.proxy.noProxy = "127.0.0.1,localhost,internal.domain";

  # Enable networking
  networking.networkmanager.enable = true;

  # Set your time zone.
  time.timeZone = "Europe/Berlin";

  # Select internationalisation properties.
  i18n.defaultLocale = "en_US.UTF-8";

  i18n.extraLocaleSettings = {
    LC_ADDRESS = "de_DE.UTF-8";
    LC_IDENTIFICATION = "de_DE.UTF-8";
    LC_MEASUREMENT = "de_DE.UTF-8";
    LC_MONETARY = "de_DE.UTF-8";
    LC_NAME = "de_DE.UTF-8";
    LC_NUMERIC = "de_DE.UTF-8";
    LC_PAPER = "de_DE.UTF-8";
    LC_TELEPHONE = "de_DE.UTF-8";
    LC_TIME = "de_DE.UTF-8";
  };

  # Enable the X11 windowing system.
  services.xserver.enable = true;
  services.rpcbind.enable = true; # needed for NFS

  # Enable the KDE Plasma Desktop Environment.
  services.xserver.displayManager.sddm.enable = true;
  services.xserver.desktopManager.plasma5.enable = true;
  # set wayland as default session
  services.xserver.displayManager.defaultSession = "plasmawayland";

  programs.partition-manager.enable = true;
  programs.zsh.enable = true;

  # use bash shell for other users
  environment.shells = with pkgs; [ bash ];

  programs.dconf.enable = true;
  programs.xwayland.enable = true;
  xdg.portal.enable = true;

  # exclude packages from plasma5
  environment.plasma5.excludePackages = with pkgs.libsForQt5; [
    elisa
    oxygen
    khelpcenter
    kcolorpicker
  ];

  # Configure keymap in X11
  services.xserver = {
    layout = "de";
    xkbVariant = "";
  };

  # Configure console keymap
  console.keyMap = "de";

  # Enable CUPS to print documents.
  services.printing.enable = true;

  ################################################
  # __     ___      _               _ _           _   _
  # \ \   / (_)_ __| |_ _   _  __ _| (_)___  __ _| |_(_) ___  _ __
  #  \ \ / /| | '__| __| | | |/ _` | | / __|/ _` | __| |/ _ \| '_ \ 
  #   \ V / | | |  | |_| |_| | (_| | | \__ \ (_| | |_| | (_) | | | |
  #    \_/  |_|_|   \__|\__,_|\__,_|_|_|___/\__,_|\__|_|\___/|_| |_|
  #
  # This sections enbales host virtualisation for:
  #  - KVM
  #  - Waydroid (android based on LineageOS)
  #  - Docker
  ################################################

  # enable rootless docker for more security
  virtualisation.docker.rootless = {
    enable = true;
    setSocketVariable = true;
  };
  # regulary clean unused docker images
  virtualisation.docker.autoPrune.enable = true;
  # add user teridax to docker group
  users.extraGroups.docker.members = [ "servostar" ];

  # KVM
  virtualisation.libvirtd.enable = true;

  # android container
  virtualisation.waydroid.enable = true;

  ################################################
  #  ____  _                     _
  # |  _ \(_)_ __   _____      _(_)_ __ ___
  # | |_) | | '_ \ / _ \ \ /\ / / | '__/ _ \
  # |  __/| | |_) |  __/\ V  V /| | | |  __/
  # |_|   |_| .__/ \___| \_/\_/ |_|_|  \___|
  #         |_|
  ################################################

  # Enable sound with pipewire.
  sound.enable = true;
  hardware.pulseaudio.enable = false;
  security.rtkit.enable = true;
  services.pipewire = {
    enable = true;
    alsa.enable = true;
    alsa.support32Bit = true;
    pulse.enable = true;
    # If you want to use JACK applications, uncomment this
    #jack.enable = true;

    # use the example session manager (no others are packaged yet so this is enabled by default,
    # no need to redefine it in your config for now)
    #media-session.enable = true;
  };

  # Enable touchpad support (enabled default in most desktopManager).
  # services.xserver.libinput.enable = true;

  programs.java.enable = true;
  programs.steam = {
     enable = true;
     remotePlay.openFirewall = true; # Open ports in the firewall for Steam Remote Play
     dedicatedServer.openFirewall = true; # Open ports in the firewall for Source Dedicated Server
  };
  hardware.opengl.driSupport32Bit = true; # Enables support for 32bit libs that steam uses

  # Allow unfree packages
  nixpkgs.config.allowUnfree = true;

  # List packages installed in system profile. To search, run:
  # $ nix search wget
  environment.systemPackages = (with pkgs; [
    (python3.withPackages(python-packages))

    conda

    virt-manager
    distrobox

    # Rust toolchain
    rustup
    libiconv
    rust-analyzer

    php
    php.packages.composer

    go

    nodejs

    sass

    devbox
    filelight
    ffmpeg-full
    openssl
    imagemagick
    gnumake
    cmake

    # Clipboard support for Wayland Session
    # used by Vim/Neovim and etc.
    wl-clipboard

    # GNU Compiler Collection and toolchain
    glibc
    gcc
    gdb
    stdenv.cc
    stdenv.cc.libc
    stdenv.cc.libc_dev

    pkg-config
    fontconfig

    # SCSI driver
    sg3_utils

    wineWowPackages.stable
    winetricks
  ]);

  # Some programs need SUID wrappers, can be configured further or are
  # started in user sessions.
  # programs.mtr.enable = true;
  # programs.gnupg.agent = {
  #   enable = true;
  #   enableSSHSupport = true;
  # };

  # List services that you want to enable:

  # Enable the OpenSSH daemon.
  # services.openssh.enable = true;

  # Or disable the firewall altogether.
  # networking.firewall.enable = false;

  # This value determines the NixOS release from which the default
  # settings for stateful data, like file locations and database versions
  # on your system were taken. It's perfectly fine and recommended to leave
  # this value at the release version of the first install of this system.
  # Before changing this value read the documentation for this option
  # (e.g. man configuration.nix or on https://nixos.org/nixos/options.html).
  system.stateVersion = "23.05"; # Did you read the comment?

  environment.sessionVariables = rec {
    _JAVA_OPTIONS = "-Dawt.useSystemAAFontSettings=lcd";

    # rust
    CARGO_TERM_COLOR = "always";
    RUST_BACKTRACE = "1";

    # Wayland for electron Ozone
    NIXOS_OZONE_WL = "1";

    GTK_THEME = "Breeze-Dark";
  };
}
